@@ -1,20 +1,19 @@
 peakXcolFiller <- function(peakXcol, inputPathPeaklist) {
-  L_2 <- dim(peakXcol)[2]
+  L3 <- dim(peakXcol)[2]
   peak_height <- peakXcol
-  peak_height[, 3:L_2] <- 0
+  peak_height[, 4:L3] <- 0
   peak_area <- peak_height
   peak_R13C <- peak_height
   ##
   colnamesPeakXcol <- colnames(peakXcol)
   ##
-  progressBARboundaries <- txtProgressBar(min = 3, max = L_2, initial = 3, style = 3)
-  for (i in 3:L_2) {
+  progressBARboundaries <- txtProgressBar(min = 4, max = L3, initial = 3, style = 3)
+  for (i in 4:L3) {
     setTxtProgressBar(progressBARboundaries, i)
-    iPeaklistFileName <- paste0("peaklist_", colnamesPeakXcol[i], ".Rdata")
-    peaklist <- loadRdata(paste0(inputPathPeaklist, "/", iPeaklistFileName))
-    x_non0 <- which(peakXcol[, i] != 0)
+    peaklist <- loadRdata(paste0(inputPathPeaklist, "/peaklist_", colnamesPeakXcol[i], ".Rdata"))
+    xNon0 <- which(peakXcol[, i] != 0)
     ##
-    for (j in x_non0) {
+    for (j in xNon0) {
       x_peak <- peakXcol[j, i]
       peak_height[j, i] <- peaklist[x_peak, 4]
       peak_area[j, i] <- peaklist[x_peak, 5]
